#
# spec file for package libyami
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   1
%define libname %{name}%{sover}
Name:           libyami
Version:        1.3.0
Release:        lp150.2.4
Summary:        Media Library with support for Intel hardware acceleration
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://github.com/01org/libyami
Source0:        https://github.com/01org/libyami/archive/%{name}-%{version}.tar.gz
#PATCH-FIX-OPENSUSE fix-build-with-libva-1.x.diff alarrosa@suse.com -- Fix build with libva-1.x in Leap 42.3
Patch0:         fix-build-with-libva-1.x.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(libv4l2)
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(libva-wayland)
%endif
BuildRequires:  pkgconfig(libva-x11)
# Intel graphics hardware only available on these platforms
ExclusiveArch:  %{ix86} x86_64

%description
Intel VA-API Media Library with support for hardware acceleration.

The library loads libva to interface with a hardware-dependent driver.

%package -n %{libname}
Summary:        Library components for %{name}
Group:          System/Libraries

%description -n %{libname}
The libyami library implements an interface to libva for Linux.
This package provides the runtime environment for libyami.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
%if 0%{?suse_version} <= 1500
%patch0 -p1
%endif

%build
autoreconf -fiv
%configure \
  --disable-static \
  --with-package-name="Libyami Media Infrastructure (openSUSE)" \
  --with-package-origin="http://www.opensuse.org/" \
  --enable-h265dec \
  --enable-vc1dec \
  --enable-h264dec \
  --enable-jpegdec \
  --enable-mpeg2dec \
  --enable-vp8dec \
  --enable-vp9dec \
  --enable-h265enc \
  --enable-h264enc \
  --enable-jpegenc \
  --enable-vp8enc \
%if 0%{?suse_version} >= 1500
  --enable-wayland="yes" \
%endif
  %{nil}
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc LICENSE.md README.md NEWS
%{_libdir}/%{name}.so.%{sover}*

%files devel
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Dec 31 2017 zaitor@opensuse.org
- Add conditional pkgconfig(libva-wayland) BuildRequires and pass
  conditional --enable-wayland="yes" to configure, build wayland
  support for selected versions of openSUSE.
* Fri Dec 22 2017 alarrosa@suse.com
- Add fix-build-with-libva-1.x.diff to fix builds with libva 1. The patch
  is only applied when building in Leap 42.x .
* Mon Dec  4 2017 adrien.plazas@suse.com
- Update to version 1.3.0:
  * Implement H.264 SVC-T new reference mode.
  * Implement H.264 low latency mode.
  * Improve v4l2 interface,support dynamic resolution change.
  * JPEG decoder fixes and Y800 support.
- Changes from version 1.2.0:
  * Depends on libva 1.8.1.
  * Improve vp9 10 bit decoder conformance.
  * Improve h265 8/10 bit decoder conformance.
  * Add decoder/display zero-copy API.
  * Use decoder/display zero copy API in v4l2 decoder.
  * Expose vp9 qp setting to the user.
  * Change API from 0.4.0 to 0.5.0 for following interface changes:
  - Get/set surface in SurfaceAllocParams.
  - Add VIDEO_DATA_MEMORY_TYPE_EXTERNAL_DMA_BUF.
* Tue Mar 21 2017 jengelh@inai.de
- Correct RPM groups again. Fix error in description.
* Sun Feb 19 2017 mpluskal@suse.com
- Cleanup spec file:
  * Run spec-clener
  * Trim not needed sections
  * Use correct rpm groups
  * Install license
  * Correct openSUSE spelling
* Sat Jan 21 2017 seanvk@posteo.de
- Update for Release 1.1.0
* Thu Jan 19 2017 seanvk@posteo.de
- Initial SPEC file
